@@ -9,16 +9,18 @@
 
 #include <QWidget>
 
-namespace Dragon {
+namespace Dragon
+{
 
-namespace Ui {
+namespace Ui
+{
 class AudioView2;
 }
 
 class AudioView2 : public QWidget
 {
     Q_OBJECT
-    
+
 public:
     explicit AudioView2(QWidget *parent = nullptr);
     ~AudioView2() override;
@@ -28,14 +30,13 @@ public:
 public Q_SLOTS:
     void enableDemo(bool enable);
     void update();
-    
+
 protected:
     void changeEvent(QEvent *e) override;
-    
+
 private:
     Ui::AudioView2 *ui;
 };
 
-
 } // namespace Dragon
 #endif // DRAGON_AUDIOVIEW2_H
